@@ -4,7 +4,7 @@ import subprocess
 from ffmpeg import probe
 
 
-def run_ffmpeg_show_progress(command):
+def run_ffmpeg_show_progress(command, ffmpeg_loglevel="info"):
     """
     This function runs an FFmpeg command and prints the following info in addition to the FFmpeg output:
         - Percentage Progress
@@ -14,23 +14,23 @@ def run_ffmpeg_show_progress(command):
     Progress: 25% | Speed: 22.3x | ETA: 1m 33s
     How to use:
     run_ffmpeg_show_progress(["ffmpeg", "-i", "input.mp4", "-c:a", "libmp3lame", "output.mp3"])
+    An optional show_ffmpeg_output paramater is available to set the value of FFmpeg's -loglevel argument.
     """
 
     index_of_filepath = command.index("-i") + 1
     filepath = command[index_of_filepath]
 
-    can_get_duration = False
-
     try:
         file_duration = float(probe(filepath)["format"]["duration"])
     except Exception:
-        print(f"\nUnable to get the duration of {filepath}:\n")
+        can_get_duration = False
+        print(f"\nUnable to get the duration of {filepath}:\nThe improved progress stats will not be shown.")
+        show_ffmpeg_output=True
     else:
         can_get_duration = True
-        print("\nUnable to get the duration of the input file. FFmpeg progress information will not be shown.\n")
 
     process = subprocess.Popen(
-        command + ["-progress", "-", "-nostats"],
+        command + ["-progress", "-", "-nostats", "-loglevel", ffmpeg_loglevel],
         stdout=subprocess.PIPE,
     )
 
@@ -38,8 +38,7 @@ def run_ffmpeg_show_progress(command):
         try:
             output = process.stdout.readline().decode("utf-8").strip()
         except Exception:
-            print("\nUnable to decode the FFmpeg output. FFmpeg progress information will not be shown.\n")
-            break
+            pass
         else:
             if can_get_duration:
                 if "out_time_ms" in output:
@@ -64,4 +63,4 @@ def run_ffmpeg_show_progress(command):
                     finally:
                         print(f"Progress: {percentage}% | Speed: {speed}x | ETA: {eta_string}", end="\r")
             else:
-                print(output)
\ No newline at end of file
+                print(output)
